@@ -5,13 +5,30 @@ from typing import TYPE_CHECKING
 import numpy as np
 
 from contourpy._contourpy import (
-    ContourGenerator, FillType, LineType, Mpl2005ContourGenerator, Mpl2014ContourGenerator,
-    SerialContourGenerator, ThreadedContourGenerator, ZInterp, max_threads,
+    ContourGenerator,
+    FillType,
+    LineType,
+    Mpl2005ContourGenerator,
+    Mpl2014ContourGenerator,
+    SerialContourGenerator,
+    ThreadedContourGenerator,
+    ZInterp,
+    max_threads,
 )
 from contourpy._version import __version__
 from contourpy.chunk import calc_chunk_sizes
-from contourpy.convert import convert_filled, convert_lines
-from contourpy.dechunk import dechunk_filled, dechunk_lines
+from contourpy.convert import (
+    convert_filled,
+    convert_lines,
+    convert_multi_filled,
+    convert_multi_lines,
+)
+from contourpy.dechunk import (
+    dechunk_filled,
+    dechunk_lines,
+    dechunk_multi_filled,
+    dechunk_multi_lines,
+)
 from contourpy.enum_util import as_fill_type, as_line_type, as_z_interp
 
 if TYPE_CHECKING:
@@ -26,8 +43,12 @@ __all__ = [
     "contour_generator",
     "convert_filled",
     "convert_lines",
+    "convert_multi_filled",
+    "convert_multi_lines",
     "dechunk_filled",
     "dechunk_lines",
+    "dechunk_multi_filled",
+    "dechunk_multi_lines",
     "max_threads",
     "FillType",
     "LineType",
@@ -41,12 +62,12 @@ __all__ = [
 
 
 # Simple mapping of algorithm name to class name.
-_class_lookup: dict[str, type[ContourGenerator]] = dict(
-    mpl2005=Mpl2005ContourGenerator,
-    mpl2014=Mpl2014ContourGenerator,
-    serial=SerialContourGenerator,
-    threaded=ThreadedContourGenerator,
-)
+_class_lookup: dict[str, type[ContourGenerator]] = {
+    "mpl2005": Mpl2005ContourGenerator,
+    "mpl2014": Mpl2014ContourGenerator,
+    "serial": SerialContourGenerator,
+    "threaded": ThreadedContourGenerator,
+}
 
 
 def _remove_z_mask(
@@ -56,8 +77,8 @@ def _remove_z_mask(
     z_array = np.ma.asarray(z, dtype=np.float64)  # type: ignore[no-untyped-call]
     z_masked = np.ma.masked_invalid(z_array, copy=False)  # type: ignore[no-untyped-call]
 
-    if np.ma.is_masked(z_masked):  # type: ignore[no-untyped-call]
-        mask = np.ma.getmask(z_masked)  # type: ignore[no-untyped-call]
+    if np.ma.is_masked(z_masked):
+        mask = np.ma.getmask(z_masked)
     else:
         mask = None
 
@@ -80,10 +101,10 @@ def contour_generator(
     z_interp: ZInterp | str | None = ZInterp.Linear,
     thread_count: int = 0,
 ) -> ContourGenerator:
-    """Create and return a :class:`~contourpy._contourpy.ContourGenerator` object.
+    """Create and return a :class:`~.ContourGenerator` object.
 
-    The class and properties of the returned :class:`~contourpy._contourpy.ContourGenerator` are
-    determined by the function arguments, with sensible defaults.
+    The class and properties of the returned :class:`~.ContourGenerator` are determined by the
+    function arguments, with sensible defaults.
 
     Args:
         x (array-like of shape (ny, nx) or (nx,), optional): The x-coordinates of the ``z`` values.
@@ -103,13 +124,17 @@ def contour_generator(
             out, other triangular corners comprising three unmasked points are contoured as usual.
             If not specified, uses the default provided by the algorithm ``name``.
         line_type (LineType or str, optional): The format of contour line data returned from calls
-            to :meth:`~contourpy.ContourGenerator.lines`, specified either as a
-            :class:`~contourpy.LineType` or its string equivalent such as ``"SeparateCode"``.
+            to :meth:`~.ContourGenerator.lines`, specified either as a :class:`~.LineType` or its
+            string equivalent such as ``"SeparateCode"``.
             If not specified, uses the default provided by the algorithm ``name``.
+            The relationship between the :class:`~.LineType` enum and the data format returned from
+            :meth:`~.ContourGenerator.lines` is explained at :ref:`line_type`.
         fill_type (FillType or str, optional): The format of filled contour data returned from calls
-            to :meth:`~contourpy.ContourGenerator.filled`, specified either as a
-            :class:`~contourpy.FillType` or its string equivalent such as ``"OuterOffset"``.
+            to :meth:`~.ContourGenerator.filled`, specified either as a :class:`~.FillType` or its
+            string equivalent such as ``"OuterOffset"``.
             If not specified, uses the default provided by the algorithm ``name``.
+            The relationship between the :class:`~.FillType` enum and the data format returned from
+            :meth:`~.ContourGenerator.filled` is explained at :ref:`fill_type`.
         chunk_size (int or tuple(int, int), optional): Chunk size in (y, x) directions, or the same
             size in both directions if only one value is specified.
         chunk_count (int or tuple(int, int), optional): Chunk count in (y, x) directions, or the
@@ -133,7 +158,7 @@ def contour_generator(
             something other than ``"threaded"`` then the ``thread_count`` will be set to ``1``.
 
     Return:
-        :class:`~contourpy._contourpy.ContourGenerator`.
+        :class:`~.ContourGenerator`.
 
     Note:
         A maximum of one of ``chunk_size``, ``chunk_count`` and ``total_chunk_count`` may be
@@ -257,6 +282,4 @@ def contour_generator(
         kwargs["thread_count"] = thread_count
 
     # Create contour generator.
-    cont_gen = cls(*args, **kwargs)
-
-    return cont_gen
+    return cls(*args, **kwargs)
